@@ -32,7 +32,7 @@ setMethod(".gbutton",
             if (!is.null(container)) {
               if(is.logical(container) && container == TRUE)
                 container = gwindow(visible=TRUE, toolkit=toolkit)
-              add(container, obj)
+              add(container, obj,...)
             }
 
             ## add handler
